%define _buildid .48

%bcond_with integration_tests

%{!?sys_python_sitelib: %global sys_python_sitelib %(%{__sys_python} -c "from distutils.sysconfig import get_python_lib; print(get_python_lib())")}

%global botocore_ver        1.8.13
%global jmespath_ver        0.9.2
%global min_docutils_ver    0.10
%global min_sphinx_ver      1.1.3
%global min_colorama_ver    0.2.5
%global min_rsa_ver         3.1.2-4.7
%global s3transfer_ver      0.1.12
%global min_futures_ver     2.2.0
%global min_pyyaml_ver      3.10

Name:		 aws-cli
Version:	 1.14.9
Release: 1%{?_buildid}%{?dist}
Summary:	 Provides a unified command line interface to Amazon Web Services
Group:		 Amazon/Tools
# aws-cli, bundled(python-s3transfer): ASL 2.0
License:	 ASL 2.0
URL:		 http://aws.amazon.com/cli/
Source0:	 https://github.com/aws/%{name}/archive/%{version}.tar.gz
# Bundle s3transfer until it stabilizes
Source1:     https://github.com/boto/s3transfer/archive/%{s3transfer_ver}.tar.gz
Patch0:      open_mock_create.patch
BuildArch:	 noarch
BuildRequires:	 system-python
BuildRequires:	 system-python-devel
# These libraries are developed in parallel with the aws-cli
BuildRequires:   %{sys_python_pkg}-botocore   = %{botocore_ver}
BuildRequires:   %{sys_python_pkg}-jmespath   = %{jmespath_ver}
# Versions taken from setup.py and requirements.txt
BuildRequires:   %{sys_python_pkg}-docutils  >= %{min_docutils_ver}
BuildRequires:   %{sys_python_pkg}-sphinx    >= %{min_sphinx_ver}
BuildRequires:   %{sys_python_pkg}-colorama  >= %{min_colorama_ver}
BuildRequires:   %{sys_python_pkg}-rsa       >= %{min_rsa_ver}
BuildRequires:   %{sys_python_pkg}-PyYAML    >= %{min_pyyaml_ver}
# Versions taken from s3transfer/setup.cfg, bundled with this package
BuildRequires:   %{sys_python_pkg}-futures   >= %{min_futures_ver}
# Needed for self checks
BuildRequires:   %{sys_python_pkg}-nose      >= 1.3.0
%if %{without integration_tests}
# Needed for the --exclude-dir flag on nose
BuildRequires:   %{sys_python_pkg}-nose-exclude
%endif
BuildRequires:   %{sys_python_pkg}-mock      >= 1.0.1
BuildRequires:   %{sys_python_pkg}-unittest2
Requires:        %{sys_python_pkg}-botocore   = %{botocore_ver}
Requires:        %{sys_python_pkg}-jmespath   = %{jmespath_ver}
Requires:        %{sys_python_pkg}-docutils  >= %{min_docutils_ver}
Requires:        %{sys_python_pkg}-colorama  >= %{min_colorama_ver}
Requires:        %{sys_python_pkg}-rsa       >= %{min_rsa_ver}
Requires:        %{sys_python_pkg}-PyYAML    >= %{min_pyyaml_ver}
Requires:        %{sys_python_pkg}-futures   >= %{min_futures_ver}
# Ensure aws s3 cp / aws s3 sync can better guess MIME types
Requires:        /etc/mime.types
# Required to run 'aws [subcommand] help'
Requires:        groff
Obsoletes:       aws-cli-zsh      <= 1.1.0
Provides:        %{name}(%sys_python_pkg) = %{version}-%{release}
Provides:        bundled(python-s3transfer) = %{s3transfer_ver}
Conflicts:       aws-cli-plugin-cloudwatch-logs < 1.2.2

# The aws-cli also uses python-requires and python-six however both are now
# bundled with botocore.

%description
This package provides a unified command line interface to Amazon Web Services.

For more information and documentation please visit http://aws.amazon.com/documentation/cli/

%prep
%setup -q
%setup -T -D -a 1
%patch0 -p1

# Bundle s3transfer and futures packages under awscli.vendored until s3transfer stabilizes
mkdir awscli/vendored
touch awscli/vendored/__init__.py

mv s3transfer-%{s3transfer_ver}/s3transfer awscli/vendored
rm -rf s3transfer-%{s3transfer_ver}

find awscli tests -type f -name '*.py' -exec \
    sed -i 's/from s3transfer/from awscli.vendored.s3transfer/g' {} \;
find awscli tests -type f -name '*.py' -exec \
    sed -i 's/import s3transfer/import awscli.vendored.s3transfer/g' {} \;


%build
%{__sys_python} setup.py build

%install
%{__sys_python} setup.py install -O1 --skip-build --root %{buildroot}

# Remove s3transfer from requires.txt as it is vendored
sed -i '/^s3transfer/d' %{buildroot}%{sys_python_sitelib}/awscli-*.egg-info/requires.txt

# Remove DOS wrapper
%__rm %{buildroot}%{_bindir}/aws.cmd

# Move zsh autocomplete to the right place
%__mkdir_p %{buildroot}%{_datadir}/zsh/site-functions/
%__mv %{buildroot}%{_bindir}/aws_zsh_completer.sh %{buildroot}%{_datadir}/zsh/site-functions/aws_zsh_completer.sh

# Move bash autocomplete to the bash_completion.d directory.
%__mkdir_p %{buildroot}%{_sysconfdir}/bash_completion.d/
%__mv %{buildroot}%{_bindir}/aws_bash_completer %{buildroot}%{_sysconfdir}/bash_completion.d/aws_bash_completer

# Originally this attempted to enable auto-complete for zsh, now we provide instructions
# on how to enable auto-completion
%__mkdir_p %{buildroot}%{_sysconfdir}/profile.d
cat >> %{buildroot}%{_sysconfdir}/profile.d/aws-cli.sh << \EOF
# This file was originally used to enable auto-completion for zsh,
# but this script ran before compinit was enabled. To setup auto-completion
# with zsh, enable compinit in the ~/.zshrc then add:
#
#   source %{_datadir}/zsh/site-functions/aws_zsh_completer.sh
#
# to then end of the ~/.zshrc file.
EOF

%check
export LC_ALL=en_US.utf8
export PYTHONPATH=%{buildroot}%{sys_python_sitelib}
export AWS_TEST_COMMAND=%{buildroot}%{_bindir}/aws
# The integrated tests require full access to AWS as well as valid AWS creds
# skip test_generate_createproduct,test_generate_createprovisioningartifact,
# and test_cp_with_error_and_warning because they require a newer mock.
/usr/bin/nosetests-%{_sys_python_version} \
    --exclude=test_warning_on_invalid_timestamp \
    --exclude=test_pipe_color \
    --exclude=test_generate_createproduct \
    --exclude=test_generate_createprovisioningartifact \
    --exclude=test_cp_with_error_and_warning \
%if %{without integration_tests}
    --exclude-dir=tests/integration \
    --exclude=test_priv_launch_key \
%endif
    %{nil}

%files
%doc LICENSE.txt README.rst
%{sys_python_sitelib}/*
%{_bindir}/aws
%{_bindir}/aws_completer
%attr(644, root, root) %{_sysconfdir}/bash_completion.d/aws_bash_completer
%{_sysconfdir}/profile.d/aws-cli.sh
%attr(644, root, root) %{_datadir}/zsh/site-functions/aws_zsh_completer.sh

%changelog
* Wed Dec 20 2017 Heath Petty <hpetty@amazon.com>
- Update to 1.14.9

* Fri Aug 11 2017 Iliana Weller <iweller@amazon.com>
- Update to 1.11.132

* Tue May 9 2017 Heath Petty <hpetty@amazon.com>
- update to 1.11.83

* Thu Dec 15 2016 Ian Weller <iweller@amazon.com>
- Remove s3transfer from requires.txt as it is vendored
- Update to 1.11.29

* Fri Nov 18 2016 Ian Weller <iweller@amazon.com>
- Require groff so help subcommands can run in containers

* Thu Nov 17 2016 Ian Weller <iweller@amazon.com>
- Update to 1.11.17

* Mon Aug 15 2016 Ian Weller <iweller@amazon.com>
- Update to 1.10.56

* Tue Jul 12 2016 Ian Weller <iweller@amazon.com>
- Unbundle python-futures

* Mon Jul 11 2016 Ian Weller <iweller@amazon.com>
- Update to 1.10.46

* Thu May 26 2016 Ian Weller <iweller@amazon.com>
- Update to 1.10.33

* Tue Mar 1 2016 Sean Kelly <seankell@amazon.com>
- Update to 1.10.8

* Fri Feb 5 2016 Ian Weller <iweller@amazon.com>
- Add dependency on mailcap for better MIME type guessing

* Tue Feb 2 2016 Ian Weller <iweller@amazon.com>
- Update to 1.10.1

* Fri Jan 15 2016 Heath Petty <hpetty@amazon.com>
- Skip test that fails intermittently during build

* Thu Jan 14 2016 Heath Petty <hpetty@amazon.com>
- Use aws_bash_completer instead of aws_cli.sh to enable CLI auto completion
- Update to 1.9.18

* Tue Dec 22 2015 Heath Petty <hpetty@amazon.com>
- Update to 1.9.15

* Mon Dec 7 2015 Ian Weller <iweller@amazon.com>
- Update to 1.9.11

* Wed Oct 28 2015 Ian Weller <iweller@amazon.com>
- Update to 1.9.1

* Fri Oct 23 2015 Ian Weller <iweller@amazon.com>
- Update to 1.9.0

* Tue Oct 13 2015 Ian Weller <iweller@amazon.com>
- Ensure pyasn1 is installed

* Fri Oct 9 2015 Ian Weller <iweller@amazon.com>
- Update to 1.8.12

* Thu Sep 24 2015 Ian Weller <iweller@amazon.com>
- Update to 1.8.7

* Fri Sep 4 2015 Ian Weller <iweller@amazon.com>
- Update to 1.8.2

* Thu Aug 13 2015 Ian Weller <iweller@amazon.com>
- Update to 1.7.45

* Tue Aug 11 2015 Ian Weller <iweller@amazon.com>
- Update to 1.7.44

* Tue Aug 4 2015 Ian Weller <iweller@amazon.com>
- Update to 1.7.42 from upstream

* Mon Jul 27 2015 Ian Weller <iweller@amazon.com>
- Update to 1.7.40 from upstream

* Mon Jul 13 2015 Sean Kelly <seankell@amazon.com>
- Update to 1.7.38 from upstream

* Tue Jul 7 2015 hpetty <hpetty@amazon.com>
- update to 1.7.36 from upstream

* Mon Jun 15 2015 Jason Green <jasg@amazon.com>
- update to 1.7.34 from upstream

* Wed Jun 10 2015 Jason Green <jasg@amazon.com>
- update to 1.7.32 from upstream

* Tue Jun 2 2015 Jason Green <jasg@amazon.com>
- update to 1.7.31 from upstream

* Tue May 26 2015 Jason Green <jasg@amazon.com>
- update to 1.7.29 from upstream

* Wed May 13 2015 hpetty <hpetty@amazon.com>
- update to 1.7.26 from upstream

* Wed Apr 22 2015 Jason Green <jasg@amazon.com>
- Update jmespath required version
- update to 1.7.23 from upstream

* Fri Apr 17 2015 Jason Green <jasg@amazon.com>
- update to 1.7.22 from upstream

* Tue Mar 17 2015 hpetty <hpetty@amazon.com>
- Update to aws-cli 1.7.14

* Thu Mar 12 2015 Tom Kirchner <tjk@amazon.com>
- Update to aws-cli 1.7.13

* Wed Mar 4 2015 hpetty <hpetty@amazon.com>
- update to 1.7.12 from upstream

* Mon Feb 9 2015 hpetty <hpetty@amazon.com>
- update to 1.7.5 from upstream

* Thu Feb 5 2015 Jason Green <jasg@amazon.com>
- Build for system python

* Thu Jan 22 2015 hpetty <hpetty@amazon.com>
- update to 1.7.3 from upstream

* Fri Jan 9 2015 Lee Trager <ltrager@amazon.com>
- Update to 1.7.0 from upstream

* Fri Dec 19 2014 Lee Trager <ltrager@amazon.com>
- Update to 1.6.10 from upstream

* Sat Dec 13 2014 Lee Trager <ltrager@amazon.com>
- Update to 1.6.9 from upstream

* Thu Dec 11 2014 Lee Trager <ltrager@amazon.com>
- Update to 1.6.8 from upstream

* Wed Dec 10 2014 Lee Trager <ltrager@amazon.com>
- Update to 1.6.7 from upstream

* Tue Dec 9 2014 Lee Trager <ltrager@amazon.com>
- Don't list out all supported services in the description since the list is growing so fast.

* Mon Dec 8 2014 Lee Trager <ltrager@amazon.com>
- Update to 1.6.6 from upstream

* Mon Dec 1 2014 Lee Trager <ltrager@amazon.com>
- Update to 1.6.5 from upstream

* Tue Nov 25 2014 Lee Trager <ltrager@amazon.com>
- Update to 1.6.4 from upstream

* Fri Nov 21 2014 Lee Trager <ltrager@amazon.com>
- Update to 1.6.3 from upstream

* Fri Nov 14 2014 hpetty <hpetty@amazon.com>
- update to 1.6.2 and add patches for cloudtrail (pull #1004)

* Tue Nov 11 2014 Lee Trager <ltrager@amazon.com>
- Update to 1.6.0 from upstream

* Tue Nov 4 2014 Lee Trager <ltrager@amazon.com>
- Update to 1.5.5 from upstream

* Tue Oct 28 2014 Lee Trager <ltrager@amazon.com>
- Update to 1.5.4 from upstream

* Mon Oct 27 2014 Lee Trager <ltrager@amazon.com>
- Update to 1.5.3 from upstream

* Mon Oct 20 2014 Lee Trager <ltrager@amazon.com>
- Update to 1.5.2 from upstream

* Thu Oct 9 2014 Lee Trager <ltrager@amazon.com>
- Update to 1.5.1 from upstream

* Tue Oct 7 2014 Lee Trager <ltrager@amazon.com>
- Update to 1.5.0 from upstream

* Wed Sep 17 2014 Lee Trager <ltrager@amazon.com>
- Update to 1.4.4 from upstream

* Fri Sep 12 2014 Lee Trager <ltrager@amazon.com>
- Update to 1.4.3 from upstream

* Tue Aug 19 2014 Lee Trager <ltrager@amazon.com>
- Update to 1.4.2 from upstream

* Tue Jul 29 2014 Lee Trager <ltrager@amazon.com>
- Update to 1.3.24 from upstream

* Tue Jul 1 2014 Lee Trager <ltrager@amazon.com>
- Update to 1.3.21 from upstream

* Wed Jun 25 2014 Lee Trager <ltrager@amazon.com>
- Update to 1.3.19 from upstream

* Tue Jun 24 2014 Lee Trager <ltrager@amazon.com>
- Update to 1.3.18 from upstream

* Fri Jun 13 2014 Lee Trager <ltrager@amazon.com>
- Require botocore 0.51.0
- Update to 1.3.17 from upstream

* Tue Jun 10 2014 Lee Trager <ltrager@amazon.com>
- Update to 1.3.16 from upstream

* Sat May 10 2014 Lee Trager <ltrager@amazon.com>
- Update to 1.3.9 from upstream

* Fri Apr 25 2014 Lee Trager <ltrager@amazon.com>
- Update to 1.3.8 from upstream

* Wed Apr 23 2014 Lee Trager <ltrager@amazon.com>
- Update to 1.3.7 from upstream

* Tue Apr 8 2014 Lee Trager <ltrager@amazon.com>
- Update to 1.3.6 from upstream

* Wed Mar 26 2014 Lee Trager <ltrager@amazon.com>
- Update to 1.3.4 from upstream

* Mon Mar 24 2014 Lee Trager <ltrager@amazon.com>
- Update to 1.3.2 from upstream

* Fri Mar 7 2014 Lee Trager <ltrager@amazon.com>
- Update to 1.3.1 from upstream

* Wed Mar 5 2014 Lee Trager <ltrager@amazon.com>
- Update to 1.3.0 from upstream

* Thu Feb 27 2014 Lee Trager <ltrager@amazon.com>
- Update to 1.2.13 from upstream

* Mon Feb 3 2014 Lee Trager <ltrager@amazon.com>
- Add patch from upstream to fix nosetest error
- Update to 1.2.12 from upstream

* Mon Jan 27 2014 Lee Trager <ltrager@amazon.com>
- Update to 1.2.11 from upstream

* Mon Jan 13 2014 Lee Trager <ltrager@amazon.com>
- Update to 1.2.10 from upstream

* Wed Dec 18 2013 Lee Trager <ltrager@amazon.com>
- Update to 1.2.8 from upstream

* Tue Dec 10 2013 Lee Trager <ltrager@amazon.com>
- Update to 1.2.7 from upstream

* Tue Dec 3 2013 Lee Trager <ltrager@amazon.com>
- Update to 1.2.6 from upstream

* Thu Nov 14 2013 Lee Trager <ltrager@amazon.com>
- Fix version string
- Update to 1.2.5 from upstream

* Sat Nov 9 2013 Lee Trager <ltrager@amazon.com>
- Update to 1.2.4 from upstream

* Thu Oct 31 2013 Lee Trager <ltrager@amazon.com>
- Update to 1.2.3 from upstream

* Wed Oct 16 2013 Lee Trager <ltrager@amazon.com>
- Add patch from upstream to fix zsh auto completion

* Fri Oct 4 2013 Lee Trager <ltrager@amazon.com>
- Disable broken test
- Update to 1.1.1 from upstream

* Fri Sep 20 2013 Lee Trager <ltrager@amazon.com>
- Remove uncessary deps and create a bcond for the integrated tests

* Thu Sep 19 2013 Lee Trager <ltrager@amazon.com>
- Turn on shell completetion by default
- Disable all tests which require Internet access
- Update to 1.1.0 from upstream

* Tue Sep 10 2013 Lee Trager <ltrager@amazon.com>
- Update to the 1.0.0 GA release!

* Tue May 7 2013 Lee Trager <ltrager@amazon.com>
- Update to 0.9.3 from upstream

* Thu Apr 25 2013 Lee Trager <ltrager@amazon.com>
- Only require major.minor and above, not micro
- Update to 0.9.2 from upstream

* Fri Apr 19 2013 Lee Trager <ltrager@amazon.com>
- Set the Python Path for the newly built aws-cli libraries

* Thu Apr 18 2013 Lee Trager <ltrager@amazon.com>
- Add missing build dependency, python-sphinx for man page creation
- Update to 0.9.1 from upstream and ship manpages

* Thu Apr 4 2013 Lee Trager <ltrager@amazon.com>
- Update to 0.8.3 from upstream

* Sun Mar 17 2013 Lee Trager <ltrager@amazon.com>
- aws-cli now requires python-colorama
- Add python-unittest2 as buildrequires for checks
- Use the new name for the zsh completer
- We no longer need to apply this patch
- Update to 0.8.2 from upstream

* Tue Mar 5 2013 Lee Trager <ltrager@amazon.com>
- Inital spec file for aws-cli

* Sat Mar 2 2013 Lee Trager <ltrager@amazon.com>
- setup complete for package aws-cli

* Fri Mar  1 2013 <ltrager@amazon.com> - 0.7.0-1
- Initial RPMization
